[][src]Enum endbasic::ast::VarType

pub enum VarType {
    Auto,
    Boolean,
    Integer,
    Text,
}

Collection of types for a variable.

Variants

Auto

Unspecified type identifier. The type is determined by the value of the variable.

Boolean

A boolean variable.

Integer

An integer variable.

Text

A string variable. This should really be called String but it would get confusing with the built-in Rust type.