[−][src]Enum endbasic::ast::VarType
Collection of types for a variable.
Variants
Unspecified type identifier. The type is determined by the value of the variable.
A boolean variable.
An integer variable.
A string variable. This should really be called String but it would get confusing with
the built-in Rust type.